#
# spec file for package saxon9
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        The SAXON XSLT Processor from Michael Kay
License:        MPL-1.0 and Apache-2.0
Group:          Productivity/Publishing/XML
# net.sf.saxon.om.XMLChar is from ASL-licensed Xerces
Name:           saxon9
Version:        9.4.0.7
Release:        12.18
Url:            http://saxon.sourceforge.net/
Source0:        https://downloads.sourceforge.net/project/saxon/Saxon-HE/9.4/saxon9-4-0-7source.zip
Source1:        %{name}.saxon.script
Source2:        %{name}.saxonq.script
Source3:        %{name}.build.script
Source4:        %{name}.1
Source5:        %{name}q.1
Source6:        https://downloads.sourceforge.net/project/saxon/Saxon-HE/9.4/saxon-resources9-4.zip
#Made from original pom file
#Source7:        http://irrational.googlecode.com/svn/trunk/maven-repo/net/sf/saxon/saxon-he/9.3.0.7/saxon-he-9.3.0.7.pom
Source7:        saxon-he-9.4.0.7.pom
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

BuildRequires:  ant
BuildRequires:  bea-stax-api
BuildRequires:  dom4j
BuildRequires:  java-devel
BuildRequires:  jdom
BuildRequires:  unzip
BuildRequires:  xml-commons-apis
BuildRequires:  xom

BuildRequires:  java-javadoc
#BuildRequires:  jdom-javadoc >= 1.0
#BuildRequires:  fop-javadoc

Requires:       bea-stax
Requires:       bea-stax-api
Provides:       jaxp_transform_impl = %{version}-%{release}

Recommends:     %{name}-scripts
Recommends:     xml-commons-resolver

# Older versions were split into multile packages
Obsoletes:      %{name}-dom < %{version}-%{release}
Provides:       %{name}-dom = %{version}-%{release}
Obsoletes:      %{name}-jdom < %{version}-%{release}
Provides:       %{name}-jdom = %{version}-%{release}
Obsoletes:      %{name}-sql < %{version}-%{release}
Provides:       %{name}-sql = %{version}-%{release}
Obsoletes:      %{name}-xom < %{version}-%{release}
Provides:       %{name}-xom = %{version}-%{release}
Obsoletes:      %{name}-xpath < %{version}-%{release}
Provides:       %{name}-xpath = %{version}-%{release}

%description
The most recent version of the open-source implementation of XSLT 2.0 and XPath
2.0, and XQuery 1.0. This provides the "basic" conformance level of these
languages: in effect, this provides all the features of the languages except
schema-aware processing. This version reflects the syntax of the final XSLT
2.0, XQuery 1.0, and XPath 2.0 Recommendations of 23 January 2007 as amended in
the second editions of those specifications where appropriate. 

%package        manual
Summary:        Manual for %{name}
Group:          Productivity/Publishing/XML

%description    manual
Manual for %{name}.

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Productivity/Publishing/XML

%description    javadoc
Javadoc for %{name}.

%package        demo
Summary:        Demos for %{name}
Group:          Productivity/Publishing/XML
Requires:       %{name} = %{version}-%{release}

%description    demo
Demonstrations and samples for %{name}.

%package        scripts
Summary:        Utility scripts for %{name}
Group:          Productivity/Publishing/XML
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-tools
Requires:       jaxp_parser_impl
Requires:       xml-commons-apis

%description    scripts
Utility scripts for %{name}.


%prep
%setup -q -c

unzip -q %{SOURCE6}
cp -p %{SOURCE3} ./build.xml

# deadNET
rm -rf net/sf/saxon/dotnet

# Depends on XQJ (javax.xml.xquery)
rm -rf net/sf/saxon/xqj

# This requires a EE edition feature (com.saxonica.xsltextn)
rm -rf net/sf/saxon/option/sql/SQLElementFactory.java

# cleanup unnecessary stuff we'll build ourselves
rm -rf docs/api
find . \( -name "*.jar" -name "*.pyc" \) -delete

%build
mkdir -p build/classes
cat >build/classes/edition.properties <<EOF
config=net.sf.saxon.Configuration
platform=net.sf.saxon.java.JavaPlatform
EOF

export CLASSPATH=%(build-classpath xml-commons-apis jdom xom bea-stax-api dom4j xml-commons-resolver12)
ant \
  -Dj2se.javadoc=%{_javadocdir}/java \
  -Djdom.javadoc=%{_javadocdir}/jdom

%install

# jars
mkdir -p %{buildroot}%{_javadir}
cp -p build/lib/saxon.jar %{buildroot}%{_javadir}/%{name}.jar

# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr build/api/* %{buildroot}%{_javadocdir}/%{name}

# demo
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -pr samples/* %{buildroot}%{_datadir}/%{name}

# scripts
mkdir -p %{buildroot}%{_bindir}
install -p -m755 %{SOURCE1} %{buildroot}%{_bindir}/%{name}
install -p -m755 %{SOURCE2} %{buildroot}%{_bindir}/%{name}q
mkdir -p %{buildroot}%{_mandir}/man1
install -p -m644 %{SOURCE4} %{buildroot}%{_mandir}/man1/%{name}.1
install -p -m644 %{SOURCE5} %{buildroot}%{_mandir}/man1/%{name}q.1

# jaxp_transform_impl ghost symlink
ln -s %{_sysconfdir}/alternatives \
  %{buildroot}%{_javadir}/jaxp_transform_impl.jar

# a simple POM
install -dm 755 %{buildroot}%{_mavenpomdir}
install -m 644 %{SOURCE7} %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
sed -i -e 's/saxon-he/saxon/' %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap

%post
update-alternatives --install %{_javadir}/jaxp_transform_impl.jar \
  jaxp_transform_impl %{_javadir}/%{name}.jar 25

%preun
{
  [ $1 -eq 0 ] || exit 0
  update-alternatives --remove jaxp_transform_impl %{_javadir}/%{name}.jar
} >/dev/null 2>&1 || :

%files
%defattr(0644,root,root,0755)
%{_javadir}/%{name}.jar
%{_mavenpomdir}/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%ghost %{_javadir}/jaxp_transform_impl.jar

%files manual
%defattr(0644,root,root,0755)
%doc doc/*.html

%files javadoc
%defattr(0644,root,root,0755)
%doc %{_javadocdir}/%{name}

%files demo
%defattr(0644,root,root,0755)
%{_datadir}/%{name}

%files scripts
%defattr(0755,root,root,0755)
%{_bindir}/%{name}
%{_bindir}/%{name}q
%attr(0644,root,root) %{_mandir}/man1/%{name}.1*
%attr(0644,root,root) %{_mandir}/man1/%{name}q.1*

%changelog
* Wed Sep 11 2013 mvyskocil@suse.com
- use add_maven_depmap from javapackages-tools
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri Jul 12 2013 toms@opensuse.org
-  Added Recommends for saxon9-scripts and xml-commons-resolver
  Usually Saxon9 is used by invocation from a Shell, thus it
  is more convenient to have the corresponding script installed
  already.
  Additionally, XML tools like Saxon needs also XML catalog support
  for mapping URIs to local paths (especially useful for DocBook users)
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Thu Feb 28 2013 archie@dellroad.org
- Update to version 9.4.0.7
* Fri Dec 21 2012 archie@dellroad.org
- Replace unmaintained options in man pages with links to website
- Fix command line flag syntax -foo bar -> -foo:bar
- Don't use CatalogResolver unless CatalogManager.properties exists
* Wed Nov 28 2012 mvyskocil@suse.com
- do not provide saxon symbol, this will be provided by saxon6
  bnc#780666 (comment10)
* Tue Nov 27 2012 archie@dellroad.org
- Update references to "saxon8" -> "saxon9" in man pages
* Tue Nov 27 2012 archie@dellroad.org
- Fix missing/incorrect classpath JARs for command line scripts
* Wed Oct 31 2012 mvyskocil@suse.com
- update to current maintenance release 9.4.0.4
  * no changelog available
- rename to saxon9 to be able to reintroduce saxon6 (XSLT 1.0)
  a request from documentation team (bnc#780666)
* Thu Jun 21 2012 cfarrell@suse.com
- license update: MPL-1.0 and Apache-2.0
  Compatible with Fedora declaration
* Fri May 18 2012 mvyskocil@suse.cz
- update to 9.3.0.4 - needed by updated xmlbeans
  * An installation wizard is provided on .NET
  * Support for XML Schema 1.1 is almost complete.
  * Support for streamed processing of XSLT is greatly extended, making transformation of very large documents much more feasible.
  * For the first time, Saxon has support for parallel processing of XSLT to take advantage of multi-core CPUs.
  * Many features from the draft 3.0 specifications are implemented.
  * The range of data-types available is extended by the provision of immutable maps.
* Tue Dec 13 2011 coolo@suse.com
- fix license to be in spdx.org format
* Wed Dec  2 2009 coolo@novell.com
- update patches, fix build
* Mon Mar 10 2008 anosek@suse.cz
- downgrade to version 6.5.5, moved Saxon 8.x to separate saxon8
  package
- based on the JPackage project, dropped two patches
  (tinytree.patch) (fragmentval.patch)
- Saxon 6 is needed because, for example, the DocBook stylesheets
  have some JAR files which contain extension functions written
  only for Saxon 6. These functions provide useful methods for
  DocBook processing. However, these are not compatible
  with the latest Saxon package.
* Wed Feb  6 2008 anosek@suse.cz
- BuildRequires: java-1.6.0-devel
* Wed May 23 2007 dbornkessel@suse.de
- make rpmllint happy:
  - delete windows '\r' from doc files
  - index jars
  - faster compiling
* Thu Mar 29 2007 dbornkessel@suse.de
- added unzip to build reqs
* Wed Oct  4 2006 dbornkessel@suse.de
- update to saxon 8.8
- build from source (no binary package)
* Tue Mar 21 2006 dbornkessel@suse.de
- removed setJava call in wrapper script (Bug #158699)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Feb 27 2004 pmladek@suse.cz
- updated to the version 6.5.3 [#35119]
  * fixes 28 bugs found in Saxon 6.5.2
- added a missing prebuilt optional saxon-fop.jar
- fixed path to saxon jars in README.SuSE
* Tue Feb 24 2004 hmacht@suse.de
- building as non-root
* Mon Nov 25 2002 pmladek@suse.cz
- added the script saxon to use StyleSheets [#21801]
- improved README.SuSE
- classes moved from /usr/lib to /usr/share
* Mon Aug  5 2002 pmladek@suse.cz
- updated to bugfix version 6.5.2
- small improvent in README.SuSE (run setJava with new better option)
* Wed Feb  6 2002 pmladek@suse.cz
- updated to version 6.5:
  * fixed number of bugs
  * important incompatible change for XSLT conformance reasons
  * you can find details on the page:
  file:/usr/share/doc/packages/saxon/doc/changes.html
- moved to noarch
* Wed Nov 28 2001 ke@suse.de
- Update to version 6.4.4:
  - 20%% performance boost.
  - Support JDOM.
- Provide convenience link (/usr/lib/saxon ->
  /usr/lib/saxon-%%{version}).
* Wed Nov 21 2001 pmladek@suse.cz
- requires changed from java2 to more universal jre1.3.x
- added README.SuSE
* Wed May 23 2001 ke@suse.de
- Initial SuSE package: Version 6.3; long pending bug partly resolved
  [#291].
